@@ -34,23 +34,12 @@ export class SendDocSubmission {
 
         shrinker.init().then(
             ({shrunkImageDB, shrunkBibDB}) => {
-                const content = this.removeAuthors(
-                    JSON.parse(JSON.stringify(this.doc.content))
-                )
+                const content = JSON.parse(JSON.stringify(this.doc.content))
                 this.uploadRevision(content, shrunkBibDB, shrunkImageDB)
             }
         )
     }
 
-    removeAuthors(contents) {
-        contents.content.forEach(part => {
-            if (part.attrs.metadata === 'authors') {
-                part.content = []
-            }
-        })
-        return contents
-    }
-
     uploadRevision(content, bibDB, imageDB) {
         post(
             '/proxy/ojs/author_submit',
