@@ -242,19 +242,20 @@ class OJSDummyTest(LiveTornadoTestCase, SeleniumHelper):
         self.driver.find_element(
             By.CSS_SELECTOR, 'a[href="register_journal/"]'
         ).click()
-        self.driver.find_element_by_id("ojs_url").send_keys(
+        self.driver.find_element(By.ID, "ojs_url").send_keys(
             "http://localhost:{}/".format(self.server_port)
         )
-        self.driver.find_element_by_id("ojs_key").send_keys("OJS_KEY")
-        self.driver.find_element_by_id("get_journals").click()
-        self.driver.find_element_by_id("editor_4").send_keys(self.editor1.id)
+        self.driver.find_element(By.ID, "ojs_key").send_keys("OJS_KEY")
+        self.driver.find_element(By.ID, "get_journals").click()
+        self.driver.find_element(By.ID, "editor_4").send_keys(self.editor1.id)
         self.driver.find_element(
             By.CSS_SELECTOR, 'button[data-id="4"]'
         ).click()
-        self.driver.find_element_by_id("editor_5").send_keys(self.editor2.id)
+        self.driver.find_element(By.ID, "editor_5").send_keys(self.editor2.id)
         self.driver.find_element(
             By.CSS_SELECTOR, 'button[data-id="5"]'
         ).click()
+        time.sleep(1)
         # Log in as user to submit an article
         self.login_user(self.user1, self.driver, self.client)
         self.driver.get(urljoin(self.base_url, "/"))
@@ -292,32 +293,81 @@ class OJSDummyTest(LiveTornadoTestCase, SeleniumHelper):
         ActionChains(self.driver).send_keys(Keys.LEFT).send_keys(
             "An abstract title"
         ).perform()
+        # Enable authors
+        self.driver.find_element(
+            By.XPATH, '//*[@id="header-navigation"]/div[3]/span'
+        ).click()
+        self.driver.find_element(
+            By.XPATH, '//*[normalize-space()="Optional sections"]'
+        ).click()
+        self.driver.find_element(
+            By.XPATH, '//*[normalize-space()="Authors"]'
+        ).click()
+        # Close menu
+        self.driver.find_element(By.CSS_SELECTOR, "#document-top").click()
+        # Add author
+        self.driver.find_element(
+            By.CSS_SELECTOR, ".article-authors button"
+        ).click()
+        self.driver.find_element(
+            By.CSS_SELECTOR, "input[name=firstname]"
+        ).send_keys("Wendy")
+        self.driver.find_element(
+            By.CSS_SELECTOR, "input[name=lastname]"
+        ).send_keys("Pox")
+        self.driver.find_element(
+            By.CSS_SELECTOR, "input[name=email]"
+        ).send_keys("wendy@pox.com")
+        self.driver.find_element(
+            By.CSS_SELECTOR, "input[name=institution]"
+        ).send_keys("Sunny University")
+
+        self.driver.find_element(
+            By.CSS_SELECTOR, ".ui-dialog-buttonset .fw-dark"
+        ).click()
         time.sleep(1)
+        # Check that there is now one author
+        self.assertEqual(
+            len(
+                self.driver.find_elements(By.CSS_SELECTOR, "span.contributor")
+            ),
+            1,
+        )
         # We submit the article to journal
-        self.driver.find_element_by_xpath(
-            '//*[@id="header-navigation"]/div[1]/span'
+        self.driver.find_element(
+            By.XPATH, '//*[@id="header-navigation"]/div[1]/span'
         ).click()
-        self.driver.find_element_by_xpath(
-            '//*[normalize-space()="Submit to journal"]'
+        self.driver.find_element(
+            By.XPATH, '//*[normalize-space()="Submit to journal"]'
         ).click()
-        self.driver.find_element_by_id("submission-journal").click()
-        self.driver.find_element_by_xpath(
-            '//*[normalize-space()="Journal of the Past"]'
+        self.driver.find_element(By.ID, "submission-journal").click()
+        self.driver.find_element(
+            By.XPATH, '//*[normalize-space()="Journal of the Past"]'
         ).click()
         self.assertEqual(
-            self.driver.find_element_by_id(
-                "submission-abstract"
+            self.driver.find_element(
+                By.ID, "submission-abstract"
             ).get_attribute("value"),
             "An abstract title",
         )
-        self.driver.find_element_by_id("submission-firstname").send_keys(
-            "Jens"
+        self.assertEqual(
+            self.driver.find_element(
+                By.ID, "submission-firstname"
+            ).get_attribute("value"),
+            "Wendy",
         )
-        self.driver.find_element_by_id("submission-lastname").send_keys(
-            "Hansen"
+        self.assertEqual(
+            self.driver.find_element(
+                By.ID, "submission-lastname"
+            ).get_attribute("value"),
+            "Pox",
         )
-        self.driver.find_element_by_xpath(
-            '//*[normalize-space()="Submit"]'
+        # Modify the lastname
+        self.driver.find_element(By.ID, "submission-lastname").send_keys(
+            " Hansen"
+        )
+        self.driver.find_element(
+            By.XPATH, '//*[normalize-space()="Submit"]'
         ).click()
         self.assertSuccessAlert("Article submitted")
         # Let OJS create a copy of the document (invisible to the original
@@ -333,8 +383,8 @@ class OJSDummyTest(LiveTornadoTestCase, SeleniumHelper):
             },
         )
         self.assertEqual(response.status_code, 201)
-        # Let OJS assign a new reviewer to the submitted article and give
-        # access
+        # Let OJS assign a new double-blind reviewer to the submitted article
+        # and give access.
         response = self.client.post(
             "/api/ojs/add_reviewer/{}/3.0.0/".format(submission_id),
             {
@@ -351,7 +401,7 @@ class OJSDummyTest(LiveTornadoTestCase, SeleniumHelper):
             {
                 "key": "OJS_KEY",
                 "user_id": 9263,
-                "access_rights": "review",
+                "review_method": "doubleanonymous",
             },
         )
         self.assertEqual(response.status_code, 200)
@@ -379,12 +429,19 @@ class OJSDummyTest(LiveTornadoTestCase, SeleniumHelper):
         WebDriverWait(self.driver, self.wait_time).until(
             EC.presence_of_element_located((By.CLASS_NAME, "editor-toolbar"))
         )
+        # Check that no authors are listed
+        self.assertEqual(
+            len(
+                self.driver.find_elements(By.CSS_SELECTOR, "span.contributor")
+            ),
+            0,
+        )
+        time.sleep(1)
         # Check that we cannot change the title
         self.driver.find_element(By.CSS_SELECTOR, ".article-title").click()
         self.driver.find_element(By.CSS_SELECTOR, ".article-title").send_keys(
             "ARGH"
         )
-        time.sleep(1)
         self.assertEqual(
             self.driver.find_element(By.CSS_SELECTOR, ".article-title").text,
             "Test",
@@ -400,23 +457,115 @@ class OJSDummyTest(LiveTornadoTestCase, SeleniumHelper):
         ).send_keys("Reviewer comment")
         self.driver.find_element(By.CSS_SELECTOR, "button.fw-dark").click()
         # Reviewer submits response to journal
-        self.driver.find_element_by_xpath(
-            '//*[@id="header-navigation"]/div[1]/span'
+        self.driver.find_element(
+            By.XPATH, '//*[@id="header-navigation"]/div[1]/span'
         ).click()
-        self.driver.find_element_by_xpath(
-            '//*[normalize-space()="Submit to journal"]'
+        self.driver.find_element(
+            By.XPATH, '//*[normalize-space()="Submit to journal"]'
         ).click()
-        self.driver.find_element_by_id("message-editor").send_keys(
+        self.driver.find_element(By.ID, "message-editor").send_keys(
             "A message just for the editor"
         )
-        self.driver.find_element_by_id("message-editor-author").send_keys(
+        self.driver.find_element(By.ID, "message-editor-author").send_keys(
             "A message for the editor and author"
         )
-        self.driver.find_element_by_id("recommendation").click()
+        self.driver.find_element(By.ID, "recommendation").click()
         ActionChains(self.driver).send_keys(Keys.DOWN).send_keys(
             Keys.DOWN
         ).send_keys(Keys.DOWN).send_keys(Keys.ENTER).perform()
-        self.driver.find_element_by_css_selector("button.fw-dark").click()
+        self.driver.find_element(By.CSS_SELECTOR, "button.fw-dark").click()
+        self.assertSuccessAlert("Review submitted")
+        # Let OJS assign a new anonymous reviewer to the submitted article
+        # and give access.
+        response = self.client.post(
+            "/api/ojs/add_reviewer/{}/3.0.0/".format(submission_id),
+            {
+                "key": "OJS_KEY",
+                "user_id": 18364,
+                "email": "reviewer2@reviews.com",
+                "username": "Reviewer2",
+            },
+        )
+        self.assertEqual(response.status_code, 201)
+        # Reviewer accepts review
+        response = self.client.post(
+            "/api/ojs/accept_reviewer/{}/3.0.0/".format(submission_id),
+            {
+                "key": "OJS_KEY",
+                "user_id": 18364,
+                "review_method": "anonymous",
+            },
+        )
+        self.assertEqual(response.status_code, 200)
+        # Get login token and log in
+        response = self.client.get(
+            "/api/ojs/get_login_token/",
+            {
+                "key": "OJS_KEY",
+                "fidus_id": str(submission_id),
+                "user_id": 18364,
+                "version": "3.0.0",
+                "is_editor": False,
+            },
+        )
+        self.assertEqual(response.status_code, 200)
+        login_token = json.loads(response.content)["token"]
+        self.driver.get(
+            urljoin(
+                self.base_url,
+                "/api/ojs/revision/{}/3.0.0/?token={}".format(
+                    submission_id, login_token
+                ),
+            )
+        )
+        WebDriverWait(self.driver, self.wait_time).until(
+            EC.presence_of_element_located((By.CLASS_NAME, "editor-toolbar"))
+        )
+        # Check that authors are listed
+        self.assertEqual(
+            len(
+                self.driver.find_elements(By.CSS_SELECTOR, "span.contributor")
+            ),
+            1,
+        )
+        time.sleep(1)
+        # Check that we cannot change the title
+        self.driver.find_element(By.CSS_SELECTOR, ".article-title").click()
+        self.driver.find_element(By.CSS_SELECTOR, ".article-title").send_keys(
+            "ARGH"
+        )
+        self.assertEqual(
+            self.driver.find_element(By.CSS_SELECTOR, ".article-title").text,
+            "Test",
+        )
+        ActionChains(self.driver).double_click(
+            self.driver.find_element(By.CSS_SELECTOR, ".article-title")
+        ).perform()
+        self.driver.find_element(
+            By.CSS_SELECTOR, 'button[title="Comment"]'
+        ).click()
+        self.driver.find_element(
+            By.CSS_SELECTOR, "#comment-editor .ProseMirror"
+        ).send_keys("Reviewer comment")
+        self.driver.find_element(By.CSS_SELECTOR, "button.fw-dark").click()
+        # Reviewer submits response to journal
+        self.driver.find_element(
+            By.XPATH, '//*[@id="header-navigation"]/div[1]/span'
+        ).click()
+        self.driver.find_element(
+            By.XPATH, '//*[normalize-space()="Submit to journal"]'
+        ).click()
+        self.driver.find_element(By.ID, "message-editor").send_keys(
+            "Another message just for the editor"
+        )
+        self.driver.find_element(By.ID, "message-editor-author").send_keys(
+            "Another message for the editor and author"
+        )
+        self.driver.find_element(By.ID, "recommendation").click()
+        ActionChains(self.driver).send_keys(Keys.DOWN).send_keys(
+            Keys.DOWN
+        ).send_keys(Keys.DOWN).send_keys(Keys.ENTER).perform()
+        self.driver.find_element(By.CSS_SELECTOR, "button.fw-dark").click()
         self.assertSuccessAlert("Review submitted")
         # Make another copy to give the original author access to the reviewed
         # version
@@ -435,19 +584,51 @@ class OJSDummyTest(LiveTornadoTestCase, SeleniumHelper):
         self.driver.get(urljoin(self.base_url, "/"))
         self.assertEqual(
             len(
-                self.driver.find_elements_by_css_selector(
-                    "table.fw-data-table tbody tr"
+                self.driver.find_elements(
+                    By.CSS_SELECTOR, "table.fw-data-table tbody tr"
+                )
+            ),
+            2,
+        )
+        self.driver.find_elements(By.CSS_SELECTOR, "a.fw-data-table-title")[
+            0
+        ].click()
+        self.assertEqual(
+            len(
+                self.driver.find_elements(
+                    By.CSS_SELECTOR, "table.fw-data-table tbody tr"
                 )
             ),
             3,
         )
+        WebDriverWait(self.driver, self.wait_time).until(
+            EC.presence_of_element_located(
+                (By.XPATH, "//h1[contains(text(),'/Submission 1/')]")
+            )
+        )
         # Enter the latest version
-        self.driver.find_elements_by_css_selector("a.fw-data-table-title")[
+        self.driver.find_elements(By.CSS_SELECTOR, "a.fw-data-table-title")[
             2
         ].click()
         WebDriverWait(self.driver, self.wait_time).until(
             EC.presence_of_element_located((By.CLASS_NAME, "editor-toolbar"))
         )
+        # Check that authors are listed
+        self.assertEqual(
+            len(
+                self.driver.find_elements(By.CSS_SELECTOR, "span.contributor")
+            ),
+            1,
+        )
+        # Check that authors are listed read only
+        self.assertEqual(
+            len(
+                self.driver.find_elements(
+                    By.CSS_SELECTOR, "div.article-authors-readonly"
+                )
+            ),
+            1,
+        )
         # Check that we can change the body
         self.driver.find_element(By.CSS_SELECTOR, ".article-body").click()
         self.driver.find_element(By.CSS_SELECTOR, ".article-body").send_keys(
@@ -458,12 +639,57 @@ class OJSDummyTest(LiveTornadoTestCase, SeleniumHelper):
             self.driver.find_element(By.CSS_SELECTOR, ".article-body").text,
             "An updated body",
         )
-        # Send in for another review round
-        self.driver.find_element_by_xpath(
-            '//*[@id="header-navigation"]/div[1]/span'
+        # Resubmit
+        self.driver.find_element(
+            By.XPATH, '//*[@id="header-navigation"]/div[1]/span'
         ).click()
-        self.driver.find_element_by_xpath(
-            '//*[normalize-space()="Submit to journal"]'
+        self.driver.find_element(
+            By.XPATH, '//*[normalize-space()="Submit to journal"]'
         ).click()
-        self.driver.find_element_by_css_selector("button.fw-dark").click()
+        self.driver.find_element(By.CSS_SELECTOR, "button.fw-dark").click()
         self.assertSuccessAlert("Resubmission successful")
+        # Journal accepts. Make another copy moving from review into
+        # copy-editing
+        response = self.client.post(
+            "/api/ojs/create_copy/{}/".format(submission_id),
+            {
+                "key": "OJS_KEY",
+                "old_version": "3.0.5",
+                "new_version": "4.0.0",
+                "granted_users": "1",
+            },
+        )
+        # Go back to overview.
+        self.driver.find_element(
+            By.CSS_SELECTOR, "#close-document-top"
+        ).click()
+        time.sleep(1)
+        # Check that there is now another document.
+        self.assertEqual(
+            len(
+                self.driver.find_elements(
+                    By.CSS_SELECTOR, "table.fw-data-table tbody tr"
+                )
+            ),
+            4,
+        )
+        # Enter the latest version
+        self.driver.find_elements(By.CSS_SELECTOR, "a.fw-data-table-title")[
+            3
+        ].click()
+        # Check that the author information is listed.
+        self.assertEqual(
+            len(
+                self.driver.find_elements(By.CSS_SELECTOR, "span.contributor")
+            ),
+            1,
+        )
+        # Check that authors are not listed read only
+        self.assertEqual(
+            len(
+                self.driver.find_elements(
+                    By.CSS_SELECTOR, "div.article-authors-readonly"
+                )
+            ),
+            0,
+        )
